/**
   A country with a name and area.
*/
import java.util.*;

public class Country
{
   /**
      Constructs a country.
      @param aName the name of the country
      @param anArea the area of the country
   */
   public Country(String aName, double anArea)
   {
      name = aName;
      area = anArea;
   }

   /**
      Gets the name of the country.
      @return the name
   */
   public String getName()
   {
      return name;
   }

   /**
      Gets the area of the country.
      @return the area
   */
   public double getArea()
   {
      return area;
   }


   /**
      A factory method that produces a Comparator<Country>
      object that compare two objects by area.
      See page 150 of the textbook.
   */
   public static Comparator<Country> comparatorByAreaFactory()
   {  // return an anonymous inner object that implements Comparator
      return new
         Comparator<Country>()
         {
            public int compare(Country country1, Country country2)
            {
               if (country1.getArea() < country2.getArea() ) return -1;
               if (country1.getArea() > country2.getArea() ) return  1;
               return 0;
		   }
     	 };
   }


   /**
      A factory method that produces a Comparator<Country>
      object that compare two objects by name.
      See page 150 of the textbook.
   */
   public static Comparator<Country> comparatorByNameFactory()
   {  // return an anonymous inner object that implements Comparator
      return new
         Comparator<Country>()
         {
            public int compare(Country country1, Country country2)
            {
               return country1.getName().compareTo(country2.getName());
            }
         };
   }


   private String name;
   private double area;
}
